@@ -4,7 +4,7 @@ __copyright__ = "(C) 2006-2009 Ola Skavhaug and Simula Research Laboratory"
 __license__   = "GNU LGPL Version 2.1."
 __cite__      = """Ola Skavhaug, Viper Visualization Software,
 http://www.fenics.org/wiki/viper/"""
-__version__ = "0.4.6"
+__version__ = "0.4.7"
 
 r"""
 Viper
@@ -566,6 +566,19 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
                 lut.SetTableValue(i, *row)
         return lut
 
+    def _make_scalarbar(self, lut):
+        scalarbar = vtk.vtkScalarBarActor()
+        scalarbar.SetLookupTable(lut)
+        scalarbar.GetPositionCoordinate().SetCoordinateSystemToNormalizedViewport()
+        scalarbar.GetPositionCoordinate().SetValue (0.1,0.01)
+        scalarbar.SetOrientationToHorizontal()
+        scalarbar.SetWidth (0.8)
+        scalarbar.SetHeight (0.14)
+        scalarbar.VisibilityOff()
+        scalarbar.GetTitleTextProperty().SetColor(0,0,0)
+        scalarbar.GetLabelTextProperty().SetColor(0,0,0)
+        return scalarbar
+
 
     def make_vtk_grid(self, mesh, cell_type=None):
         """Based on a mesh with the methods cells() and coordinates(), construct a vtk grid."""
@@ -838,10 +851,7 @@ Additional parameters: vmin, vmax, lutfile, wireframe, celltype, title
             self.ren.SetBackground(1, 1, 1)
 
             lut = self._make_lut(autorange=(vmin, vmax))
-            scalarbar = vtk.vtkScalarBarActor()
-            scalarbar.SetLookupTable(lut)
-            scalarbar.VisibilityOff()
-            self.scalarbar = scalarbar
+            self.scalarbar = self._make_scalarbar(lut)
             self.lut = lut
         else:
             self.ren.RemoveAllViewProps()
@@ -922,6 +932,7 @@ Inherited from vtk:
             axes.GetProperty().SetColor(0,0,0)
             axes.SetAxisTitleTextProperty(tprop)
             axes.SetAxisLabelTextProperty(tprop)
+            axes.SetCornerOffset(0)
             ren.AddViewProp(axes)
 
     def simple_outline(self):
@@ -1028,17 +1039,7 @@ Inherited from vtk:
             self.ren.SetBackground(1, 1, 1)
 
             lut = self._make_lut(autorange=(vmin, vmax))
-            scalarbar = vtk.vtkScalarBarActor()
-            scalarbar.SetLookupTable(lut)
-            scalarbar.GetPositionCoordinate().SetCoordinateSystemToNormalizedViewport()
-            scalarbar.GetPositionCoordinate().SetValue (0.1,0.01)
-            scalarbar.SetOrientationToHorizontal()
-            scalarbar.SetWidth (0.8)
-            scalarbar.SetHeight (0.14)
-            scalarbar.VisibilityOff()
-            scalarbar.GetTitleTextProperty().SetColor(0,0,0)
-            scalarbar.GetLabelTextProperty().SetColor(0,0,0)
-            self.scalarbar = scalarbar
+            self.scalarbar = self._make_scalarbar(lut)
             self.lut = lut
         else:
             self.ren.RemoveAllViewProps()
