@@ -3,8 +3,8 @@
 __copyright__ = "(C) 2006-2009 Ola Skavhaug and Simula Research Laboratory"
 __license__   = "GNU LGPL Version 2.1."
 __cite__      = """Ola Skavhaug, Viper Visualization Software,
-http://www.fenics.org/wiki/viper/"""
-__version__ = "0.4.6"
+http://www.fenicsproject.org"""
+__version__ = "0.4.7"
 
 __doc__ = """
 Viper for DOLFIN
@@ -29,6 +29,11 @@ import ffc
 
 _plotter = None
 
+plottable = [('mesh',             (Mesh,)),
+             ('genericfunction',  (GenericFunction,)),
+             ('functionplotdata', (FunctionPlotData,)),
+             ('meshfunction',     tuple(eval("MeshFunction%s" % t) for t in ["Int", "UInt", "Double", "Bool"]))]
+
 class Viper(ViperBase):
     """A custom Viper sub-class for visualizing meshes and fields in Dolfin."""
 
@@ -60,23 +65,14 @@ class Viper(ViperBase):
         args, kwargs = self.parse_input(args, kwargs)
         if "noninteractive" in args: kwargs["interactive"] = False
 
-        if isinstance(data, dolfin.Mesh):
-            self.plottype = "mesh"
-            self.plot_mesh(data, *args, **kwargs)
-        elif isinstance(data, GenericFunction):
-            self.plottype = "genericfunction"
-            self.plot_genericfunction(data, *args, **kwargs)
-        elif isinstance(data, FunctionPlotData):
-            self.plottype = "functionplotdata"
-            self.plot_functionplotdata(data, *args, **kwargs)
-        elif isinstance(data, tuple([eval("MeshFunction%s" % x) for x in ["Int", "UInt", "Double", "Bool"]])):
-            self.plottype = "meshfunction"
-            self.plot_meshfunction(data, *args, **kwargs)
-        else:
-            from dolfin.project import project
-            print "using project"
-            data = project(data)
-            self.plot(data, *args, **kwargs)
+        for plottype, classes in plottable:
+            if isinstance(data, classes):
+                self.plottype = plottype
+                plot_method = getattr(self, "plot_%s" % plottype)
+                plot_method(data, *args, **kwargs)
+                return
+
+        raise TypeError("Type not supported for plotting, %s" % str(type(data)))
 
     def plot_mesh(self, data, *args, **kwargs):
         self.rescale = False
@@ -163,7 +159,7 @@ class Viper(ViperBase):
                 # Use vector norms for scalar coloring
                 self.x = numpy.sqrt(self.x[:,0]**2 + self.x[:,1]**2 + self.x[:,2]**2)
                 self.filter = self.warp_vector(self.displacement)
-                (self.iren, self.renWin, self.ren) = self.simple_plotter(self.filter, vmin, vmax, wireframe=False)
+                (self.iren, self.renWin, self.ren) = self.simple_plotter(self.filter, vmin, vmax, wireframe=wireframe)
 
         self.iren.Initialize()
         self._update(self.x)
@@ -239,7 +235,7 @@ class Viper(ViperBase):
         mesh_dim = self.mesh.topology().dim()
         dim = data.dim()
         size = data.size()
-        values = data.values()
+        values = data.array()
         self.vtkgrid = self.make_vtk_grid(self.mesh)
         self.filter = self.vtkgrid
         self.x = numpy.array(values, dtype='d')
@@ -253,7 +249,7 @@ class Viper(ViperBase):
                 # Create a vertex valued meshfunction and plot that
                 self.mesh.init(dim)
                 vertices = type(data)(self.mesh, 0)
-                vertex_values = vertices.values()
+                vertex_values = vertices.array()
                 vertex_values[:] = 0
                 con20 = self.mesh.topology()(dim,0)
                 for facet in xrange(self.mesh.num_faces()):
@@ -359,7 +355,7 @@ class Viper(ViperBase):
             self.vtkgrid = self.make_vtk_grid(self.mesh)
             self.filter = self.vtkgrid
             self.update_scalar_mapper(self.filter)
-            self.x = numpy.array(data.values(), dtype='d')
+            self.x = numpy.array(data.array(), dtype='d')
         else:
             print "Unknown plottype %s. Can't update" % (self.plottype,)
 
@@ -368,20 +364,16 @@ class Viper(ViperBase):
 
 class PlotManager(object):
     def __init__(self):
-        self.plots = {}
-        self.index = None # By default, use automatic plotting
-        self.length = 0
         import random
         self.random = random
+        self.reset()
 
     def figure(self, index):
         self.index = index
 
     def reset(self):
-        del self.plots
         self.plots = {}
-        self.index = None
-        self.length = 0
+        self.index = None # By default, use automatic plotting
 
     def plot(self, plot_object, *args, **kwargs):
         if self.index is None:
@@ -430,12 +422,22 @@ def plot(data, *args, **kwargs):
     global _plotter
     if _plotter is None:
         _plotter = PlotManager()
+    n_old_plots = len(_plotter.plots)
 
     interactive = False
     if kwargs.has_key("interactive"):
         interactive = kwargs["interactive"]
         kwargs["interactive"] = False
     fig = _plotter.plot(data, **kwargs)
+
+    if n_old_plots > 0 and kwargs.get('autoposition', True):
+        x, y   = fig.window_size
+        nx, ny = n_old_plots%3, n_old_plots//3
+        fig.renWin.SetPosition(nx*x, ny*y)
+        # The actual positioning seems to be indeterministic, but at least
+        # they don't overlap (completely).
+        #print (nx*x,ny*y), fig.renWin.GetPosition()
+
     if interactive:
         _plotter.interactive()
     return fig
